package com.example.what_the_fantasy.ui.components

import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column

import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxHeight
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.size
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.rounded.*
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.IconButtonColors
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.painter.Painter
import androidx.compose.ui.graphics.vector.ImageVector
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.example.what_the_fantasy.R
import com.example.what_the_fantasy.ui.theme.*

@Composable
fun NavBar(onProfile : Boolean = false ,
           onFavorite : Boolean = false ,
           onAccueil : Boolean = false ,
           onQuiz : Boolean = false ,

           navControllerProfil: (Int) -> Unit,
           navControllerFavorite: () -> Unit,
           navControllerAccueil: () -> Unit,
           navControllerQuiz: () -> Unit,

           content : @Composable ()-> Unit ) {

    Column(
        modifier = Modifier
            .fillMaxSize()
    ) {
        Row(
            modifier = Modifier
                .fillMaxWidth()
                .height(70.dp)
                .background(colorNavBar),
            Arrangement.SpaceBetween,
            verticalAlignment = Alignment.Bottom
        ) {
            ButtonIconVectorInt(Icons.Rounded.AccountCircle,"Profile",{},onProfile)


            Button(onClick = {},
                colors = ButtonDefaults.buttonColors(containerColor = Color.Transparent)
            ) {
                Text("Theme", fontSize = 25.sp, color = Color.White)
            }

        }

        Box(modifier = Modifier.background(Color.Black).fillMaxHeight(0.92f)){
            content()
        }

        Row(modifier = Modifier
            .background(colorNavBar)
            .fillMaxSize(),
            horizontalArrangement = Arrangement.SpaceAround,
            verticalAlignment = Alignment.CenterVertically
        ) {

            ButtonIconVector(Icons.Rounded.Favorite,"Favorite",navControllerFavorite,onFavorite)

            ButtonIconPainter(painterResource(R.mipmap.ic_launcher_foreground),"Accueil",navControllerAccueil,onAccueil)

            ButtonIconVector(Icons.Rounded.Create,"Quiz",navControllerQuiz,onQuiz)
        }
    }
}
@Composable
fun ButtonIconVector(img : ImageVector, name : String, nav : ()->Unit ,onPage : Boolean){
    IconButton(onClick = {nav()},
        enabled = !onPage,
        colors = IconButtonColors(Color.Transparent,Color.White,//couleur quand il n'est pas selectionné
                                Color.Transparent, colorButtonNav),//couleur quand il est selectionné
        modifier = Modifier
            .size(60.dp)
    ) {
        Icon(img,
            contentDescription = name,
            modifier = Modifier
                .size(60.dp)
        )
    }
}
@Composable
fun ButtonIconVectorInt(img : ImageVector, name : String, nav : (Int)->Unit ,onPage : Boolean){
    IconButton(onClick = {},
        enabled = !onPage,
        colors = IconButtonColors(Color.Transparent,Color.White,//couleur quand il n'est pas selectionné
                                Color.Transparent, colorButtonNav),//couleur quand il est selectionné
        modifier = Modifier
            .size(60.dp)
    ) {
        Icon(img,
            contentDescription = name,
            modifier = Modifier
                .size(60.dp)
        )
    }
}


@Composable
fun ButtonIconPainter(img : Painter, name : String, nav : ()->Unit,onPage : Boolean){
    IconButton(onClick = {nav()},
        enabled = !onPage,
        colors = IconButtonColors(Color.Transparent,Color.White,//couleur quand il n'est pas selectionné
                                Color.Transparent, colorButtonNav),//couleur quand il est selectionné
        modifier = Modifier
            .size(60.dp)
    ) {
        Icon(img,
            contentDescription = name,
            modifier = Modifier
                .size(60.dp)
        )
    }
}
