package com.example.what_the_fantasy.ui.navigations

import androidx.compose.runtime.Composable
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.rememberNavController
import com.example.what_the_fantasy.ui.screens.AccueilPage
import com.example.what_the_fantasy.ui.screens.FavoritePage
import com.example.what_the_fantasy.ui.screens.LoginPage
import com.example.what_the_fantasy.ui.screens.ProfilPage
import com.example.what_the_fantasy.ui.screens.QuizAccueil
import com.example.what_the_fantasy.ui.screens.QuizEndPage
import com.example.what_the_fantasy.ui.screens.QuizPage
import com.example.what_the_fantasy.ui.screens.QuotePage
import com.example.what_the_fantasy.ui.screens.SearchPage
import com.example.what_the_fantasy.ui.screens.SignUpPage
import com.example.what_the_fantasy.ui.screens.SubmitQuotePage



sealed class Destination(val route: String) {
    data object Login : Destination("Login")
    data object Accueil : Destination("Accueil")
    data object Favorite : Destination("Favorite")
    data object Profil : Destination("Profil/{userIndex}") {  // Ajout du paramètre userIndex
        fun createRoute(userIndex: Int) = "Profil/$userIndex"  // Fonction pour créer la route avec l'index
    }

    data object Quote : Destination("Quote")
    data object Search : Destination("Search")
    data object SignUp : Destination("SignUp")
    data object SubmitQuote : Destination("SubmitQuote")

    data object QuizAccueil : Destination("QuizAccueil")
    data object QuizPage : Destination("QuizPage")
    data object QuizEndPage : Destination("QuizEndPage")
}

@Composable
fun AppNavigator() {
    val navController = rememberNavController()

    NavHost(navController, startDestination = Destination.Accueil.route) {
        composable(Destination.Login.route) { LoginPage(
            navControllerSignUp = { navController.navigate(Destination.SignUp.route) },
            navControllerProfil = { userIndex ->
                navController.navigate(Destination.Profil.createRoute(userIndex))  // Passe l'index à Profil
            }
        ) }
        composable(Destination.Accueil.route) { AccueilPage(
            navFavorite = { navController.navigate(Destination.Favorite.route) },
            navQuiz =  { navController.navigate(Destination.QuizAccueil.route) }
        ) }
        composable(Destination.Favorite.route) { FavoritePage(
            navAccueil = { navController.navigate(Destination.Accueil.route) },
            navQuiz =  { navController.navigate(Destination.QuizAccueil.route) }
        ) }
        composable(Destination.Profil.route) { backStackEntry ->
            // Récupère l'index passé dans la route
            val userIndex = backStackEntry.arguments?.getString("userIndex")?.toInt() ?: -1
            ProfilPage(index = userIndex,
                navController = navController,


            )
        }
        composable(Destination.Quote.route) { QuotePage() }
        composable(Destination.Search.route) { SearchPage() }
        composable(Destination.SignUp.route) { SignUpPage(navController) }
        composable(Destination.SubmitQuote.route) { SubmitQuotePage() }



        composable(Destination.QuizAccueil.route) { QuizAccueil(
            navFavorite = { navController.navigate(Destination.Favorite.route) },
            navAccueil = { navController.navigate(Destination.Accueil.route) },

            navControllerQuizPage =  { navController.navigate(Destination.QuizPage.route) },
            navControllerQuizEndPage =  { navController.navigate(Destination.QuizEndPage.route) }
        ) }

        composable(Destination.QuizPage.route) { QuizPage(
                navControllerQuiz = {navController.navigate(Destination.QuizAccueil.route)},
                navControllerQuizEndPage = {navController.navigate(Destination.QuizEndPage.route)}
        ) }
        composable(Destination.QuizEndPage.route) { QuizEndPage(
            points = 5,
            idQuiz = 1
        ) }

    }
}

